@@ -18,11 +18,17 @@ class UserInteraction(ex.BaseExtension[ex.ExtUserInteraction]):
             setattr(self, method, getattr(self.return_object, method))
 
     def select(self, title: str, choices: List[str]) -> str:
-        return ""
+        """Ask user to select one of the choices"""
 
     def print(self, message: Any) -> None:
         """Prints the given object into console using rich-text"""
 
+    def checkbox(self, title: str, choices: List[str]) -> List[str]:
+        """Ask user to select one or more choices"""
+
+    def confirm(self, title: str) -> bool:
+        """Ask user to confirm a decision"""
+
     def load_extension(self, extension: ex.ExtUserInteraction):
         """Loading extension"""
         self.return_object = extension
